Date: 01 4, 2002 11:21:36 AM

# lengthr

## Purpose

Pre action that succeeds if leaf token length is in the range of lengths (lengthNumber1,lengthNumber2), inclusive.

## Syntax

<fromRuleEltNumber,toRuleEltNumber>lengthr(lengthNumber1,lengthNumber2);

fromRuleEltNumber - type: int
toRuleEltNumber - type: int
lengthNumber1 - type: int
lengthNumber2 - type: int

## Returns

## Remarks

## Example

## See Also

length, numrange, PRE Actions